% Matlab code to re-produce some of the results in:
%
%  "Portfolio Sorts and Tests of Cross-Sectional Patterns in Expected Returns"
%    by Andrew J. Patton and Allan Timmermann
% Paper available at:
% http://www.economics.ox.ac.uk/members/andrew.patton/research.html
%
%
%  Andrew Patton and Allan Timmermann
%
%  9 February 2008
%
%  REVISED 23 May 2008s


bootreps = 1000
% this program takes about 54 seconds to run on a 2.4GHz machine with 3GB of memory, with bootreps=1000, and wolak_reps=0

wolak_sims = 2  
% this should be set to at least 100, and preferably 1000, if the Wolak tests are to be used. (if they are to be ignored then set to 2, say.)
% takes  18.0 minutes for wolak_sims=100
% takes 169.4 minutes for wolak_sims=1000
% in our application the results did not change much at all for sims=100 or sims=1000.

tic;

data_directory = 'c:\core\work\sorts\';

%%%%%%%%%% LOADING IN THE DATA ON DECILE PORTFOLIO SORTS, USING VALUE-WEIGHTED PORTFOLIOS

% MONTHLY RETURNS, 1963.07 to 2006.12 (522 months)
% data originally downloaded from Ken French's web site
data1 = xlsread([data_directory,'PT08_data_ALL.xls'],'ME',      'K446:T967');
data2 = xlsread([data_directory,'PT08_data_ALL.xls'],'BE-ME',   'K446:T967');
data3 = xlsread([data_directory,'PT08_data_ALL.xls'],'CF-P',    'K146:T667');
data4 = xlsread([data_directory,'PT08_data_ALL.xls'],'E-P',     'K146:T667');
data5 = xlsread([data_directory,'PT08_data_ALL.xls'],'D-P',     'K434:T955');
data6 = xlsread([data_directory,'PT08_data_ALL.xls'],'Momentum','B440:K961');
data7 = xlsread([data_directory,'PT08_data_ALL.xls'],'STR',     'B451:K972');
data8 = xlsread([data_directory,'PT08_data_ALL.xls'],'LTR',     'B392:K913');
dataALL = [data1,data2,data3,data4,data5,data6,data7,data8];

% ANNUAL RETURNS,
% 1963 to 2006, 44 years
% data originally downloaded from Ken French's web site
data1a = xlsread([data_directory,'PT08_data_ALL.xls'],'ME',      'K1974:T2017');
data2a = xlsread([data_directory,'PT08_data_ALL.xls'],'BE-ME',   'K1974:T2017');
data3a = xlsread([data_directory,'PT08_data_ALL.xls'],'CF-P',    'K1349:T1392');
data4a = xlsread([data_directory,'PT08_data_ALL.xls'],'E-P',     'K1349:T1392');
data5a = xlsread([data_directory,'PT08_data_ALL.xls'],'D-P',     'K1949:T1992');
data6a = xlsread([data_directory,'PT08_data_ALL.xls'],'Momentum','B1962:K2005');
data7a = xlsread([data_directory,'PT08_data_ALL.xls'],'STR',     'B1984:K2027');
data8a = xlsread([data_directory,'PT08_data_ALL.xls'],'LTR',     'B1862:K1905');
dataALLann = [data1a,data2a,data3a,data4a,data5a,data6a,data7a,data8a];

% MONTHLY RETURNS, all available data (will be different lengths)
% data originally downloaded from Ken French's web site
data1b = xlsread([data_directory,'PT08_data_ALL.xls'],'ME',      'K2:T967');
data2b = xlsread([data_directory,'PT08_data_ALL.xls'],'BE-ME',   'K2:T967');
data3b = xlsread([data_directory,'PT08_data_ALL.xls'],'CF-P',    'K2:T667');
data4b = xlsread([data_directory,'PT08_data_ALL.xls'],'E-P',     'K2:T667');
data5b = xlsread([data_directory,'PT08_data_ALL.xls'],'D-P',     'K2:T955');
data6b = xlsread([data_directory,'PT08_data_ALL.xls'],'Momentum','B2:K961');
data7b = xlsread([data_directory,'PT08_data_ALL.xls'],'STR',     'B2:K972');
data8b = xlsread([data_directory,'PT08_data_ALL.xls'],'LTR',     'B2:K913');

% ANNUAL RETURNS, all available data (will be different lengths)
% data originally downloaded from Ken French's web site
data1c = xlsread([data_directory,'PT08_data_ALL.xls'],'ME',      'K1938:T2017');
data2c = xlsread([data_directory,'PT08_data_ALL.xls'],'BE-ME',   'K1938:T2017');
data3c = xlsread([data_directory,'PT08_data_ALL.xls'],'CF-P',    'K1338:T1392');
data4c = xlsread([data_directory,'PT08_data_ALL.xls'],'E-P',     'K1338:T1392');
data5c = xlsread([data_directory,'PT08_data_ALL.xls'],'D-P',     'K1914:T1992');
data6c = xlsread([data_directory,'PT08_data_ALL.xls'],'Momentum','B1926:K2005');
data7c = xlsread([data_directory,'PT08_data_ALL.xls'],'STR',     'B1948:K2027');
data8c = xlsread([data_directory,'PT08_data_ALL.xls'],'LTR',     'B1830:K1905');



%%%%%%%%% RE-PRODUCING TABLE 1 FROM THE PAPER

table1 = -999.99*ones(10,8);
table1(:,1) = mean(data1b)';
table1(:,2) = mean(data2b(:,end:-1:1))';
table1(:,3) = mean(data3b(:,end:-1:1))';
table1(:,4) = mean(data4b(:,end:-1:1))';
table1(:,5) = mean(data5b(:,end:-1:1))';
table1(:,6) = mean(data6b(:,end:-1:1))';
table1(:,7) = mean(data7b)';
table1(:,8) = mean(data8b)';

info.fmt = '%10.4f';
info.cnames = strvcat('ME','BE-ME','CF-P','E-P','D-P','Momentum','ST reversal','LT reversal');
info.rnames = strvcat('.','top','2','3','4','5','6','7','8','9','bottom');
sprintf(['Table 1: Estimates of expected returns for decile portfolios'])
mprint(table1,info)


%%%%%%%%% RE-PRODUCING TABLE 2-A FROM THE PAPER
%%%%%%%%% IMPLEMENTING THE "MR" TEST ON THESE PORTFOLIOS
direction = [-1;1;1;1;1;1;-1;-1];  % look for a decreasing pattern or an increasing pattern
block_length = 10;
rand_state = 1234;

table5 = -999.99*ones(8,6);
tic;
for ii=1:8;
    temp_str = ['data123 = data',int2str(ii),'b;'];  % setting the place-holder data123 equal to the relevant data set (data"i"b)
    evalin('base',temp_str);

    temp = MR_test_20(data123,bootreps,direction(ii),block_length,rand_state);
    table5(ii,1) = abs(diff(mean(data123(:,[1,end]))));  % difference in sample means of top and bottom portfolios
    table5(ii,2:5) = temp';
    
    temp = wolak_test_3((data123(:,2:end)-data123(:,1:end-1))*direction(ii),wolak_sims);
    table5(ii,6:7) = temp';
end

% (minor variations in the bootstrap p-values may appear due to the random
% number generator starting at a different point)
clear info;
info.fmt = '%10.4f';
info.rnames = strvcat('.','ME','BE-ME','CF-P','E-P','D-P','Momentum','ST reversal','LT reversal');
info.cnames = strvcat('top-bottom','t-stat','t-pval','Wolak-pval','MR-pval');
sprintf(['Table 2A: Test statistics for monthly portfolios sorted on a single variable: mixed starting dates'])
mprint(table5(:,[1:3,6,5]),info)

%%%%%%%%% RE-PRODUCING TABLE 2-B FROM THE PAPER
%%%%%%%%% IMPLEMENTING THE "MR" TEST ON THESE PORTFOLIOS
direction = [-1;1;1;1;1;1;-1;-1];  % look for a decreasing pattern or an increasing pattern
rand_state = 1234;

table5a = -999.99*ones(8,5);
for ii=1:8;
    temp_str = ['data123 = data',int2str(ii),'c;'];  % setting the place-holder data123 equal to the relevant data set (data"i"b)
    evalin('base',temp_str);

    temp = MR_test_20(data123,bootreps,direction(ii),block_length,rand_state);
    table5a(ii,1) = abs(diff(mean(data123(:,[1,end]))));  % difference in sample means of top and bottom portfolios
    table5a(ii,2:5) = temp';
    
    temp = wolak_test_3((data123(:,2:end)-data123(:,1:end-1))*direction(ii),wolak_sims);
    table5a(ii,6:7) = temp';
   
end
% this part takes about 2.14 seconds for all eight portfolios, with bootreps=1000 on a 2.4GHz machine with 3GB of memory

% (minor variations in the bootstrap p-values may appear due to the random
% number generator starting at a different point)
clear info;
info.fmt = '%10.4f';
info.rnames = strvcat('.','ME','BE-ME','CF-P','E-P','D-P','Momentum','ST reversal','LT reversal');
info.cnames = strvcat('top-bottom','t-stat','t-pval','Wolak-pval','MR-pval');
sprintf(['Table 2B: Test statistics for annual portfolios sorted on a single variable: mixed starting dates'])
mprint(table5a(:,[1,2,3,6,5]),info)


%%%%%%%%% RE-PRODUCING TABLE 3 FROM THE PAPER
table3 = -999.99*ones(10,8);
for ii=1:8;
    temp = mean(dataALL(:,(ii-1)*10+1:ii*10))';
    if ii==2 | ii==3 | ii==4 | ii==5 | ii==6;  % then we reverse the order, so that the predicted pattern is increasing
        table3(:,ii) = temp(end:-1:1);
    else
        table3(:,ii) = temp;
    end
end

clear info;
info.fmt = '%10.4f';
info.rnames = strvcat('.','top','2','3','4','5','6','7','8','9','bottom');
info.cnames = strvcat('ME','BE-ME','CF-P','E-P','D-P','Momentum','ST reversal','LT reversal');
sprintf(['Table 3: Estimates of expected returns for decile portfolios: 1963:07-2006:12'])
mprint(table3,info)


%%%%%%%%% RE-PRODUCING TABLE 4-A FROM THE PAPER
%%%%%%%%% IMPLEMENTING THE "MR" TEST ON THESE PORTFOLIOS
direction = [-1;1;1;1;1;1;-1;-1];  % look for a decreasing pattern or an increasing pattern
rand_state = 1234;

table4 = -999.99*ones(8,7);
for ii=1:8;
    temp = MR_test_20(dataALL(:,(ii-1)*10+1:ii*10),bootreps,direction(ii),block_length,rand_state);
    table4(ii,1) = abs(diff(mean(dataALL(:,[(ii-1)*10+1,ii*10]))));  % difference in sample means of top and bottom portfolios
    table4(ii,2:5) = temp';

    temp = wolak_test_3( (dataALL(:,1+(ii-1)*10+1:ii*10) - dataALL(:,(ii-1)*10+1:ii*10-1))*direction(ii),wolak_sims);
    table4(ii,6:7) = temp';
end


% (minor variations in the bootstrap p-values may appear due to the random
% number generator starting at a different point)
clear info;
info.fmt = '%10.4f';
info.rnames = strvcat('.','ME','BE-ME','CF-P','E-P','D-P','Momentum','ST reversal','LT reversal');
info.cnames = strvcat('top-bottom','t-stat','t-pval','Wolak-pval','MR-pval');
sprintf(['Table 4A: Test statistics for monthly portfolios sorted on a single variable: 1963:07-2006:12'])
mprint(table4(:,[1,2,3,6,5]),info)


%%%%%%%%% RE-PRODUCING TABLE 4-B FROM THE PAPER
%%%%%%%%% IMPLEMENTING THE "MR" TEST ON ANNUAL PORTFOLIOS
direction = [-1;1;1;1;1;1;-1;-1];  % look for a decreasing pattern or an increasing pattern
rand_state = 1234;

table4a = -999.99*ones(8,7);
for ii=1:8;
    temp = MR_test_20(dataALLann(:,(ii-1)*10+1:ii*10),bootreps,direction(ii),block_length,rand_state);
    table4a(ii,1) = abs(diff(mean(dataALLann(:,[(ii-1)*10+1,ii*10]))));  % difference in sample means of top and bottom portfolios
    table4a(ii,2:5) = temp';
    
    temp = wolak_test_3( (dataALLann(:,1+(ii-1)*10+1:ii*10) - dataALLann(:,(ii-1)*10+1:ii*10-1))*direction(ii),wolak_sims);
    table4a(ii,6:7) = temp';
end
% this part takes about 2.14 seconds for all eight portfolios, with bootreps=1000 on a 2.4GHz machine with 3GB of memory

% (minor variations in the bootstrap p-values may appear due to the random
% number generator starting at a different point)
clear info;
info.fmt = '%10.4f';
info.rnames = strvcat('.','ME','BE-ME','CF-P','E-P','D-P','Momentum','ST reversal','LT reversal');
info.cnames = strvcat('top-bottom','t-stat','t-pval','Wolak-pval','MR-pval');
sprintf(['Table 4B: Test statistics for annual portfolios sorted on a single variable: 1963-2006'])
mprint(table4a(:,[1,2,3,6,5]),info)


%%%%%%%%% RE-PRODUCING FIGURE 1 FROM THE PAPER
% (minor variations in the bootstrap p-values may appear due to the random
% number generator starting at a different point)

temp = mean(data3)';
figure(1001),subplot(2,1,1),plot((1:10)',temp,'o-','LineWidth',1);hold on;
plot([5,6],temp(5:6),'r.-',[3,4],temp(3:4),'r.-','LineWidth',1);
set(gca,'XTickLabel',{'Low';'2';'3';'4';'5';'6';'7';'8';'9';'High'});
xlabel('Cashflow to price decile'),...
    axis([0.8,10.2,0.67,1.5]),...
    ylabel('Average return'),...
    title('Value-weighted cashflow-to-price portfolio returns, 1963-2006'),...
    text(4,1.40,strcat(['t-statstic = ',     num2str(    table4(3,2),'%10.3f')])),...
    text(4,1.35,strcat(['t-test p-value = ', num2str(    table4(3,3),'%10.3f')])),...
    text(4,1.30,strcat(['MR test p-value = ',num2str(table4(3,5),'%10.3f')]));hold off;

temp = mean(data7)';
figure(1001),subplot(2,1,2),plot((1:10)',temp,'o-','LineWidth',1);hold on;
plot([1,2],temp(1:2),'r.-',[7,8],temp(7:8),'r.-','LineWidth',1);
set(gca,'XTickLabel',{'Losers';'2';'3';'4';'5';'6';'7';'8';'9';'Winners'});
xlabel('Short-term performance decile'),...
    axis([0.8,10.2,0.67,1.5]),...
    ylabel('Average return'),...
    title('Value-weighted short-term reversal portfolio returns, 1963-2006'),...
    text(4,1.40,strcat(['t-statstic = ',     num2str(    table4(7,2),'%10.3f')])),...
    text(4,1.35,strcat(['t-test p-value = ', num2str(    table4(7,3),'%10.3f')])),...
    text(4,1.30,strcat(['MR test p-value = ',num2str(table4(7,5),'%10.3f')]));hold off;


%%%%%%%%%% NOW LOOKING AT THE TWO-WAY SORTED PORTFOLIOS
% MONTHLY RETURNS, all available data (will be different lengths)
% data originally downloaded from Ken French's web site
data12b = xlsread([data_directory,'PT08_data_ALL.xls'],'ME_BEME',  'B2:Z967');
data16b = xlsread([data_directory,'PT08_data_ALL.xls'],'ME_MOM',   'B2:Z961');
data17b = xlsread([data_directory,'PT08_data_ALL.xls'],'ME_STR',   'B2:Z972');
data18b = xlsread([data_directory,'PT08_data_ALL.xls'],'ME_LTR',   'B2:Z913');

% there are some missing values for some of these (early in the sample) so will drop those months
data12b = data12b(find(min(data12b,[],2)>-99.99),:);
data16b = data16b(find(min(data16b,[],2)>-99.99),:);
data17b = data17b(find(min(data17b,[],2)>-99.99),:);
data18b = data18b(find(min(data18b,[],2)>-99.99),:);

% creating a 3D matrix of returns on the two-way sorted portfolios, which makes it easier to see what's going on
data12 = nines(5,5,size(data12b,1));
data16 = nines(5,5,size(data16b,1));
data17 = nines(5,5,size(data17b,1));
data18 = nines(5,5,size(data18b,1));
for ii=1:5;
    data12(ii,:,:) = data12b(:,5*(ii-1)+1:5*ii)';
    data16(ii,:,:) = data16b(:,5*(ii-1)+1:5*ii)';
    data17(ii,:,:) = data17b(:,5*(ii-1)+1:5*ii)';
    data18(ii,:,:) = data18b(:,5*(ii-1)+1:5*ii)';
end

data12r = data12(:,end:-1:1,:);  % reversing order of columns so that expected returns are decreasing from top to bottom, and left to right
data16r = data16(:,end:-1:1,:);  % reversing order of columns
data17r = data17;  % no need to reverse these columns
data18r = data18;


%%%%%%%%% RE-PRODUCING TABLE 5 FROM THE PAPER
table5a = mean(data12r,3);
table5b = mean(data16r,3);
table5c = mean(data17r,3);
table5d = mean(data18r,3);


clear info;
info.fmt = '%10.4f';
info.rnames = strvcat('.','small','2','3','4','big');
info.cnames = strvcat('top','2','3','4','bottom');
sprintf(['Table 5A: Estimates of expected returns for 5x5 double-sorted portfolios - ME x BE/ME'])
mprint(table5a,info)
sprintf(['Table 5B: Estimates of expected returns for 5x5 double-sorted portfolios - ME x Momentum'])
mprint(table5b,info)
sprintf(['Table 5C: Estimates of expected returns for 5x5 double-sorted portfolios - ME x ST reversal'])
mprint(table5c,info)
sprintf(['Table 5D: Estimates of expected returns for 5x5 double-sorted portfolios - ME x LT reversal'])
mprint(table5d,info)


%%%%%%%%% RE-PRODUCING TABLE 6 FROM THE PAPER

% need to create a matrix with all the differences to be tested
data12a = []; data16a = []; data17a = []; data18a = [];
for ii=1:5;
    data12a = [data12a,squeeze(data12r(ii,2:end,:)-data12r(ii,1:end-1,:))'];  % all the column differences
    data12a = [data12a,squeeze(data12r(2:end,ii,:)-data12r(1:end-1,ii,:))'];  % all the row differences

    data16a = [data16a,squeeze(data16r(ii,2:end,:)-data16r(ii,1:end-1,:))'];  % all the column differences
    data16a = [data16a,squeeze(data16r(2:end,ii,:)-data16r(1:end-1,ii,:))'];  % all the row differences

    data17a = [data17a,squeeze(data17r(ii,2:end,:)-data17r(ii,1:end-1,:))'];  % all the column differences
    data17a = [data17a,squeeze(data17r(2:end,ii,:)-data17r(1:end-1,ii,:))'];  % all the row differences

    data18a = [data18a,squeeze(data18r(ii,2:end,:)-data18r(ii,1:end-1,:))'];  % all the column differences
    data18a = [data18a,squeeze(data18r(2:end,ii,:)-data18r(1:end-1,ii,:))'];  % all the row differences
end
% all these differences should be mean zero under the null, and strictly negative in expectation under the alternative

temp1 = MR_test_20(data12a,bootreps,-2,block_length,rand_state);
temp2 = MR_test_20(data16a,bootreps,-2,block_length,rand_state);
temp3 = MR_test_20(data17a,bootreps,-2,block_length,rand_state);
temp4 = MR_test_20(data18a,bootreps,-2,block_length,rand_state);

temp5 = wolak_test_3(-data12a,wolak_sims);  % each of these takes quite a while. 251 seconds for wolak_simss=100
temp6 = wolak_test_3(-data16a,wolak_sims);
temp7 = wolak_test_3(-data17a,wolak_sims);
temp8 = wolak_test_3(-data18a,wolak_sims);


table6 = -999.99*ones(4,7);
table6(1,4:5) = temp1(3:4)';
table6(2,4:5) = temp2(3:4)';
table6(3,4:5) = temp3(3:4)';
table6(4,4:5) = temp4(3:4)';
table6(1,6:7) = temp5';
table6(2,6:7) = temp6';
table6(3,6:7) = temp7';
table6(4,6:7) = temp8';

temp = nwest(squeeze(data12r(1,1,:)-data12r(5,5,:)),ones(length(data12r),1),floor(4*((length(data12r)/100)^(2/9))));
table6(1,1:3) = [temp.beta,temp.tstat,2*normcdf(-abs(temp.tstat))];
temp = nwest(squeeze(data16r(1,1,:)-data16r(5,5,:)),ones(length(data16r),1),floor(4*((length(data16r)/100)^(2/9))));
table6(2,1:3) = [temp.beta,temp.tstat,2*normcdf(-abs(temp.tstat))];
temp = nwest(squeeze(data17r(1,1,:)-data17r(5,5,:)),ones(length(data17r),1),floor(4*((length(data17r)/100)^(2/9))));
table6(3,1:3) = [temp.beta,temp.tstat,2*normcdf(-abs(temp.tstat))];
temp = nwest(squeeze(data18r(1,1,:)-data18r(5,5,:)),ones(length(data18r),1),floor(4*((length(data18r)/100)^(2/9))));
table6(4,1:3) = [temp.beta,temp.tstat,2*normcdf(-abs(temp.tstat))];

clear info;
info.fmt = '%10.4f';
info.rnames = strvcat('.','ME x BE/ME','ME x mom','ME x STR','ME x LTR');
info.cnames = strvcat('top-bottom','tstat','pval','MR-pval','Wolak-pval');
sprintf(['Table 6: Test statistics for double sorted portfolios'])
mprint(table6(:,[1,2,3,5,6]),info)

%%%%%%%%% RE-PRODUCING TABLE 7 FROM THE PAPER

%%% Table 7a
table7a1 = -999.99*ones(7,7);
table7a1(1:5,1:5) = table5a;
table7a1(7,7) = table6(1,5);  
% doing the tests for individual rows and columns
for ii=1:5;
    temp = MR_test_20(squeeze(data12r(2:end,ii,:)-data12r(1:end-1,ii,:))',bootreps,-2,block_length,rand_state);
    table7a1(6,ii) = temp(4);
    temp = MR_test_20(squeeze(data12r(ii,2:end,:)-data12r(ii,1:end-1,:))',bootreps,-2,block_length,rand_state);
    table7a1(ii,6) = temp(4);
end
temp2 = [];
temp3 = [];
for ii=1:5;
    temp2 = [temp2,squeeze(data12r(2:end,ii,:)-data12r(1:end-1,ii,:))'];
    temp3 = [temp3,squeeze(data12r(ii,2:end,:)-data12r(ii,1:end-1,:))'];
end
temp = MR_test_20(temp2,bootreps,-2,block_length,rand_state);
table7a1(7,3) = temp(4);
temp = MR_test_20(temp3,bootreps,-2,block_length,rand_state);
table7a1(3,7) = temp(4);

clear info;
info.fmt = '%10.4f';
info.rnames = strvcat('.','small','2','3','4','big','MR pval','Joint MR pval');
info.cnames = strvcat('top','2','3','4','bottom','MR pval','Joint MR pval');
sprintf(['Table 7A: Conditional and joint monotonicity tests for double-sorted portfolios, ME x BE/ME'])
mprint(table7a1,info)


%%% Table 7b
table7b1 = -999.99*ones(7,7);
table7b1(1:5,1:5) = table5b;
table7b1(7,7) = table6(2,5);  
% doing the tests for individual rows and columns
for ii=1:5;
    temp = MR_test_20(squeeze(data16r(2:end,ii,:)-data16r(1:end-1,ii,:))',bootreps,-2,block_length,rand_state);
    table7b1(6,ii) = temp(4);
    temp = MR_test_20(squeeze(data16r(ii,2:end,:)-data16r(ii,1:end-1,:))',bootreps,-2,block_length,rand_state);
    table7b1(ii,6) = temp(4);
end
temp2 = [];
temp3 = [];
for ii=1:5;
    temp2 = [temp2,squeeze(data16r(2:end,ii,:)-data16r(1:end-1,ii,:))'];
    temp3 = [temp3,squeeze(data16r(ii,2:end,:)-data16r(ii,1:end-1,:))'];
end
temp = MR_test_20(temp2,bootreps,-2,block_length,rand_state);
table7b1(7,3) = temp(4);
temp = MR_test_20(temp3,bootreps,-2,block_length,rand_state);
table7b1(3,7) = temp(4);

clear info;
info.fmt = '%10.4f';
info.rnames = strvcat('.','small','2','3','4','big','MR pval','Joint MR pval');
info.cnames = strvcat('top','2','3','4','bottom','MR pval','Joint MR pval');
sprintf(['Table 7B: Conditional and joint monotonicity tests for double-sorted portfolios, ME x momentum'])
mprint(table7b1,info)

%%% Table 7c
table7c1 = -999.99*ones(7,7);
table7c1(1:5,1:5) = table5c;
table7c1(7,7) = table6(3,5);  
% doing the tests for individual rows and columns
for ii=1:5;
    temp = MR_test_20(squeeze(data17r(2:end,ii,:)-data17r(1:end-1,ii,:))',bootreps,-2,block_length,rand_state);
    table7c1(6,ii) = temp(4);
    temp = MR_test_20(squeeze(data17r(ii,2:end,:)-data17r(ii,1:end-1,:))',bootreps,-2,block_length,rand_state);
    table7c1(ii,6) = temp(4);
end
temp2 = [];
temp3 = [];
for ii=1:5;
    temp2 = [temp2,squeeze(data17r(2:end,ii,:)-data17r(1:end-1,ii,:))'];
    temp3 = [temp3,squeeze(data17r(ii,2:end,:)-data17r(ii,1:end-1,:))'];
end
temp = MR_test_20(temp2,bootreps,-2,block_length,rand_state);
table7c1(7,3) = temp(4);
temp = MR_test_20(temp3,bootreps,-2,block_length,rand_state);
table7c1(3,7) = temp(4);

clear info;
info.fmt = '%10.4f';
info.rnames = strvcat('.','small','2','3','4','big','MR pval','Joint MR pval');
info.cnames = strvcat('top','2','3','4','bottom','MR pval','Joint MR pval');
sprintf(['Table 7C: Conditional and joint monotonicity tests for double-sorted portfolios, ME x STR'])
mprint(table7c1,info)

%%% Table 7d
table7d1 = -999.99*ones(7,7);
table7d1(1:5,1:5) = table5d;
table7d1(7,7) = table6(4,5); 
% doing the tests for individual rows and columns
for ii=1:5;
    temp = MR_test_20(squeeze(data18r(2:end,ii,:)-data18r(1:end-1,ii,:))',bootreps,-2,block_length,rand_state);
    table7d1(6,ii) = temp(4);
    temp = MR_test_20(squeeze(data18r(ii,2:end,:)-data18r(ii,1:end-1,:))',bootreps,-2,block_length,rand_state);
    table7d1(ii,6) = temp(4);
end
temp2 = [];
temp3 = [];
for ii=1:5;
    temp2 = [temp2,squeeze(data18r(2:end,ii,:)-data18r(1:end-1,ii,:))'];
    temp3 = [temp3,squeeze(data18r(ii,2:end,:)-data18r(ii,1:end-1,:))'];
end
temp = MR_test_20(temp2,bootreps,-2,block_length,rand_state);
table7d1(7,3) = temp(4);
temp = MR_test_20(temp3,bootreps,-2,block_length,rand_state);
table7d1(3,7) = temp(4);

clear info;
info.fmt = '%10.4f';
info.rnames = strvcat('.','small','2','3','4','big','MR pval','Joint MR pval');
info.cnames = strvcat('top','2','3','4','bottom','MR pval','Joint MR pval');
sprintf(['Table 7D: Conditional and joint monotonicity tests for double-sorted portfolios, ME x LTR'])
mprint(table7d1,info)

toc
